==> nextcloud-32.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/password_policy/l10n/it.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "La password è scaduta, usa il metodo di password dimenticata per ripristinarla.",
    "Password must not have been used recently before." : "La password non deve essere stata utilizzata recentemente.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "La password è presente in un elenco di 1.000.000 di password comuni. Rendila unica.",
    "Password is present in compromised password list. Please choose a different password." : "La password è presente in un elenco di password compromesse. Scegli una password diversa.",
    "Password needs to be at least %s characters long." : "La password deve essere composta da almeno %s caratteri.",
    "Password needs to contain at least one numeric character." : "La password deve contenere almeno un carattere numerico.",
    "Password needs to contain at least one special character." : "La password deve contenere almeno un carattere speciale.",
    "Password needs to contain at least one lower and one upper case character." : "La password deve contenere almeno un carattere minuscolo e uno maiuscolo.",
    "Password policy" : "Criterio della password",
    "Allows admins to configure a password policy" : "Consente agli amministratori di configurare un criterio per le password",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Consente all'amministratore di definire determinati pre-requisiti per le password, ad es. forzare una lunghezza minima",
    "General password policies" : "Criteri generali sulle password",
    "Add policy set" : "Aggiungi set di policy",
    "Login policies" : "Politiche di accesso",
    "Password history size" : "Dimensione cronologia password",
    "Number of passwords to keep (securely hashed) to prevent users from reusing previously used passwords." : "Numero di password da conservare (sottoposte a hash sicuro) per impedire agli utenti di riutilizzare password già utilizzate in precedenza.",
    "Maximum login attempts" : "Numero massimo di tentativi di accesso",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "Numero di tentativi di accesso prima che l'account utente venga disattivato fino a intervento manuale. (0 per nessun limite)",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Si noti che questa opzione è pensata per proteggere gli account sotto attacco. Gli account disattivati devono essere riattivati a mano da un amministratore. Gli aggressori che tentano di indovinare le password degli account avranno il loro indirizzo IP bloccato dalla protezione bruteforce indipendentemente da questa impostazione.",
    "Number of days until user password expires" : "Numero di giorni per la scadenza della password dell'utente",
    "Password expiration" : "Scadenza  password",
    "Warning: enabling password expiration is nowadays considered a security risk by several security agencies." : "Attenzione: abilitare la scadenza della password è oggi considerato un rischio per la sicurezza da numerose agenzie di sicurezza.",
    "Remove policy" : "Rimuovi policy",
    "Minimum password length" : "Lunghezza minima della password",
    "Forbid common passwords" : "Vieta le password comuni",
    "Enforce upper and lower case characters" : "Forza i caratteri maiuscoli e minuscoli",
    "Enforce numeric characters" : "Forza i caratteri numerici",
    "Enforce special characters" : "Forza i caratteri speciali",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Verifica la password con l'elenco di password compromesse di haveibeenpwnd.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Questo controllo crea un hash della password e invia i primi 5 caratteri di questo hash alle API di haveibeenpwned.com per recuperare un elenco di tutti gli hash che iniziano con questi caratteri. Poi controlla se la password dell'istanza Nextcloud è presente nei risultati.",
    "Account password policies" : "Criteri per le password degli account",
    "Share password policies" : "Condividi le policy sulle password"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-33.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/password_policy/l10n/it.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "La password è scaduta, usa il metodo di password dimenticata per ripristinarla.",
    "Password must not have been used recently before." : "La password non deve essere stata utilizzata recentemente.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "La password è presente in un elenco di 1.000.000 di password comuni. Rendila unica.",
    "Password is present in compromised password list. Please choose a different password." : "La password è presente in un elenco di password compromesse. Scegli una password diversa.",
    "Password needs to be at least %s characters long." : "La password deve essere composta da almeno %s caratteri.",
    "Password needs to contain at least one numeric character." : "La password deve contenere almeno un carattere numerico.",
    "Password needs to contain at least one special character." : "La password deve contenere almeno un carattere speciale.",
    "Password needs to contain at least one lower and one upper case character." : "La password deve contenere almeno un carattere minuscolo e uno maiuscolo.",
    "Password policy" : "Criterio della password",
    "Allows admins to configure a password policy" : "Consente agli amministratori di configurare un criterio per le password",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Consente all'amministratore di definire determinati pre-requisiti per le password, ad es. forzare una lunghezza minima",
    "General password policies" : "Criteri generali sulle password",
    "Add policy set" : "Aggiungi set di policy",
    "Login policies" : "Politiche di accesso",
    "Password history size" : "Dimensione cronologia password",
    "Number of passwords to keep (securely hashed) to prevent users from reusing previously used passwords." : "Numero di password da conservare (sottoposte a hash sicuro) per impedire agli utenti di riutilizzare password già utilizzate in precedenza.",
    "Maximum login attempts" : "Numero massimo di tentativi di accesso",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "Numero di tentativi di accesso prima che l'account utente venga disattivato fino a intervento manuale. (0 per nessun limite)",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Si noti che questa opzione è pensata per proteggere gli account sotto attacco. Gli account disattivati devono essere riattivati a mano da un amministratore. Gli aggressori che tentano di indovinare le password degli account avranno il loro indirizzo IP bloccato dalla protezione bruteforce indipendentemente da questa impostazione.",
    "Number of days until user password expires" : "Numero di giorni per la scadenza della password dell'utente",
    "Password expiration" : "Scadenza  password",
    "Warning: enabling password expiration is nowadays considered a security risk by several security agencies." : "Attenzione: abilitare la scadenza della password è oggi considerato un rischio per la sicurezza da numerose agenzie di sicurezza.",
    "Remove policy" : "Rimuovi policy",
    "Minimum password length" : "Lunghezza minima della password",
    "Forbid common passwords" : "Vieta le password comuni",
    "Enforce upper and lower case characters" : "Forza i caratteri maiuscoli e minuscoli",
    "Enforce numeric characters" : "Forza i caratteri numerici",
    "Enforce special characters" : "Forza i caratteri speciali",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Verifica la password con l'elenco di password compromesse di haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Questo controllo crea un hash della password e invia i primi 5 caratteri di questo hash alle API di haveibeenpwned.com per recuperare un elenco di tutti gli hash che iniziano con questi caratteri. Poi controlla se la password dell'istanza Nextcloud è presente nei risultati.",
    "Account password policies" : "Criteri per le password degli account",
    "Share password policies" : "Condividi le policy sulle password"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
